@@ -1,4 +1,4 @@
-from telliot_core.data.query_catalog import query_catalog
+from telliot_core.api import query_catalog
 
 for q in query_catalog.find(active=True):
     print(f"{q.tag:15} {q.query_id} {q.descriptor}")
