@@ -1,7 +1,9 @@
 from telliot_core.queries.catalog import Catalog
 from telliot_core.queries.legacy_query import LegacyRequest
+from telliot_core.queries.price.aws_spot_price import AwsSpotPrice
 from telliot_core.queries.price.spot_price import SpotPrice
 
+"""Main instance of the Query Catalog."""
 query_catalog = Catalog()
 
 # --------------------------------------------------------------------------------------
@@ -46,3 +48,15 @@ query_catalog.add_entry(
     q=SpotPrice(asset="ohm", currency="eth"),
     active=True,
 )
+
+query_catalog.add_entry(
+    tag="vsq-usd-spot",
+    title="VSQ/USD spot price",
+    q=SpotPrice(asset="vsq", currency="usd"),
+)
+
+query_catalog.add_entry(
+    tag="aws-spot-zone-us-east-1f-instance-i3.16xlarge",
+    title="AWS Spot Price",
+    q=AwsSpotPrice(zone="us-east-1f", instance="i3.16xlarge"),
+)
