@@ -75,8 +75,6 @@ class RPCEndpoint(Base):
             msg = f"Could not connect to RPC endpoint at: {self.url}"
             logger.error(e)
             logger.error(msg)
-            print(e)
-            print(msg)
 
         return connected
 
@@ -89,6 +87,13 @@ default_endpoint_list = [
         url="wss://mainnet.infura.io/ws/v3/{INFURA_API_KEY}",
         explorer="https://etherscan.io",
     ),
+    RPCEndpoint(
+        chain_id=3,
+        provider="Infura",
+        network="ropsten",
+        url="wss://ropsten.infura.io/ws/v3{INFURA_API_KEY}",
+        explorer="https://ropsten.etherscan.io",
+    ),
     RPCEndpoint(
         chain_id=4,
         provider="Infura",
@@ -103,6 +108,13 @@ default_endpoint_list = [
         url="https://rpc-mainnet.matic.network",
         explorer="https://matic.network",
     ),
+    RPCEndpoint(
+        chain_id=122,
+        provider="Fuse",
+        network="mainnet",
+        url="https://rpc.fuse.io",
+        explorer="https://explorer.fuse.io",
+    ),
     RPCEndpoint(
         chain_id=80001,
         provider="Matic",
