@@ -9,12 +9,16 @@ import clamfig
 import yaml
 
 from telliot_core.model.base import Base
+from telliot_core.queries.abi_query import AbiQuery
 from telliot_core.queries.query import OracleQuery
 
 
 @dataclass
 class CatalogEntry(Base):
-    """Query Catalog Entry"""
+    """Query Catalog Entry
+
+    An entry in the query Catalog containing relevant information about the query
+    """
 
     #: Catalog ID
     tag: str
@@ -23,6 +27,7 @@ class CatalogEntry(Base):
     descriptor: str
     query_id: str
     active: bool
+    abi: str
 
     @property
     def query(self) -> OracleQuery:
@@ -33,13 +38,25 @@ class CatalogEntry(Base):
 
 @dataclass
 class Catalog(Base):
+    """Query Catalog
+
+    The query catalog contains one `CatalogEntry` object for each valid query in the Tellor network.
+    It is stored as a mapping of query names (i.e. tags) to `CatalogEntry` objects.
+    """
+
     _entries: Dict[str, CatalogEntry] = field(default_factory=dict)
 
     def add_entry(self, tag: str, title: str, q: OracleQuery, active: bool = True) -> None:
+        """Add a new entry to the catalog."""
 
         if tag in self._entries:
             raise Exception(f"Error adding query entry: {tag} already exists")
 
+        if isinstance(q, AbiQuery):
+            abi = json.dumps(q.abi)
+        else:
+            abi = ""
+
         entry = CatalogEntry(
             tag=tag,
             title=title,
@@ -47,6 +64,7 @@ class Catalog(Base):
             descriptor=q.descriptor,
             query_id=f"0x{q.query_id.hex()}",
             active=active,
+            abi=abi,
         )
 
         self._entries[tag] = entry
@@ -59,7 +77,7 @@ class Catalog(Base):
         query_type: Optional[str] = None,
         active: Optional[bool] = None,
     ) -> List[OracleQuery]:
-        """Returns a list of queries matching the search parameters"""
+        """Search the query catalog for matching entries."""
 
         entries = []
         for entry in self._entries.values():
@@ -98,6 +116,7 @@ class Catalog(Base):
             lines.append(f"| Active | `{entry.active}` |")
             lines.append(f"| Type | `{entry.query_type}` |")
             lines.append(f"| Descriptor | `{entry.descriptor}` |")
+            lines.append(f"| Encoding ABI | `{entry.abi}` |")
             lines.append(f"| Query ID | `{entry.query_id}` |")  # type: ignore
             lines.append(f"| Query data | `0x{entry.query.query_data.hex()}` |")
             lines.append("")
