@@ -9,7 +9,7 @@ from typing import Tuple
 
 from telliot_core.dtypes.float_type import UnsignedFloatType
 from telliot_core.dtypes.value_type import ValueType
-from telliot_core.queries.json_query import JsonQuery
+from telliot_core.queries.abi_query import AbiQuery
 from telliot_core.utils.home import TELLIOT_CORE_ROOT
 
 logger = logging.getLogger(__name__)
@@ -36,21 +36,23 @@ spot_price_pairs = get_spot_price_pairs()
 
 
 @dataclass
-class SpotPrice(JsonQuery):
+class SpotPrice(AbiQuery):
     """Returns the spot price of a cryptocurrency asset in the given currency.
 
     Attributes:
-
-        asset: Asset ID (see data specifications for a full list of supported assets)
-
-        currency: Currency (default = `usd`)
+        asset:
+            Asset ID (see data specifications for a full list of supported assets)
+        currency:
+            Currency (default = `usd`)
 
     """
 
     asset: str
-
     currency: str
 
+    #: ABI used for encoding/decoding parameters
+    abi = [{"name": "asset", "type": "string"}, {"name": "currency", "type": "string"}]
+
     @property
     def value_type(self) -> ValueType:
         """Data type returned for a SpotPrice query.
@@ -61,6 +63,7 @@ class SpotPrice(JsonQuery):
         return UnsignedFloatType(abi_type="ufixed256x18", packed=False)
 
     def __post_init__(self) -> None:
+        """Validate parameters."""
         self.asset = self.asset.lower()
         self.currency = self.currency.lower()
 
